<h1 align="center">Convention</h1>

Trip Teknologi's Codebase Convention.

Getting Started
---

Installation :

```
$ pip install tripteki-pylint
```

How to use :

- Publish `pylintrc` file in the root of your project's directory with running :

```
tripteki-pylint
```

Usage
---

`pylint --recursive=y .`

Author
---

- Trip Teknologi ([@tripteki](https://linkedin.com/company/tripteki))
- Hasby Maulana ([@hsbmaulana](https://linkedin.com/in/hsbmaulana))